summaryrefslogtreecommitdiffstats
path: root/kmymoney2/mymoney/storage/imymoneyserialize.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/mymoney/storage/imymoneyserialize.h')
-rw-r--r--kmymoney2/mymoney/storage/imymoneyserialize.h94
1 files changed, 47 insertions, 47 deletions
diff --git a/kmymoney2/mymoney/storage/imymoneyserialize.h b/kmymoney2/mymoney/storage/imymoneyserialize.h
index a0c12ca..c900687 100644
--- a/kmymoney2/mymoney/storage/imymoneyserialize.h
+++ b/kmymoney2/mymoney/storage/imymoneyserialize.h
@@ -26,8 +26,8 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qstring.h>
-#include <qvaluelist.h>
+#include <tqstring.h>
+#include <tqvaluelist.h>
// ----------------------------------------------------------------------------
// Project Includes
@@ -59,14 +59,14 @@ public:
// general get functions
virtual const MyMoneyPayee user(void) const = 0;
- virtual const QDate creationDate(void) const = 0;
- virtual const QDate lastModificationDate(void) const = 0;
+ virtual const TQDate creationDate(void) const = 0;
+ virtual const TQDate lastModificationDate(void) const = 0;
virtual unsigned int currentFixVersion(void) const = 0;
virtual unsigned int fileFixVersion(void) const = 0;
// general set functions
virtual void setUser(const MyMoneyPayee& val) = 0;
- virtual void setCreationDate(const QDate& val) = 0;
+ virtual void setCreationDate(const TQDate& val) = 0;
virtual void setFileFixVersion(const unsigned int v) = 0;
/**
* This method is used to get a SQL reader for subsequent database access
@@ -86,26 +86,26 @@ public:
* therefor be called as last operation when loading from a
* file.
*
* @param val QDate of last modification
*/
- virtual void setLastModificationDate(const QDate& val) = 0;
+ virtual void setLastModificationDate(const TQDate& val) = 0;
/**
* This method returns a list of accounts inside the storage object.
*
* @param list reference to QValueList receiving the account objects
*
* @note The standard accounts will not be returned
*/
- virtual void accountList(QValueList<MyMoneyAccount>& list) const = 0;
+ virtual void accountList(TQValueList<MyMoneyAccount>& list) const = 0;
/**
* This method returns a list of the institutions
* inside a MyMoneyStorage object
*
* @return QMap containing the institution information
*/
- virtual const QValueList<MyMoneyInstitution> institutionList(void) const = 0;
+ virtual const TQValueList<MyMoneyInstitution> institutionList(void) const = 0;
/**
* This method is used to pull a list of transactions from the file
@@ -113,25 +113,25 @@ public:
* that match the filter passed as argument. If the filter is empty,
* the whole journal will be returned.
*
* @param list reference to QValueList<MyMoneyTransaction> receiving
* the set of transactions
* @param filter MyMoneyTransactionFilter object with the match criteria
*/
- virtual void transactionList(QValueList<MyMoneyTransaction>& list, MyMoneyTransactionFilter& filter) const = 0;
+ virtual void transactionList(TQValueList<MyMoneyTransaction>& list, MyMoneyTransactionFilter& filter) const = 0;
/**
* This method returns whether a given transaction is already in memory, to avoid
* reloading it from the database
*/
- virtual bool isDuplicateTransaction(const QString&) const = 0;
+ virtual bool isDuplicateTransaction(const TQString&) const = 0;
/**
* This method returns a list of the payees
* inside a MyMoneyStorage object
*
* @return QValueList<MyMoneyPayee> containing the payee information
*/
- virtual const QValueList<MyMoneyPayee> payeeList(void) const = 0;
+ virtual const TQValueList<MyMoneyPayee> payeeList(void) const = 0;
/**
* This method returns a list of the scheduled transactions
@@ -139,19 +139,19 @@ public:
* list of the transactions, all arguments should be used with their
* default arguments.
*/
- virtual const QValueList<MyMoneySchedule> scheduleList(const QString& = QString(),
+ virtual const TQValueList<MyMoneySchedule> scheduleList(const TQString& = TQString(),
const MyMoneySchedule::typeE = MyMoneySchedule::TYPE_ANY,
const MyMoneySchedule::occurenceE = MyMoneySchedule::OCCUR_ANY,
const MyMoneySchedule::paymentTypeE = MyMoneySchedule::STYPE_ANY,
- const QDate& = QDate(),
- const QDate& = QDate(),
+ const TQDate& = TQDate(),
+ const TQDate& = TQDate(),
const bool = false) const = 0;
/**
* This method returns a list of security objects that the engine has
* knowledge of.
*/
- virtual const QValueList<MyMoneySecurity> securityList(void) const = 0;
+ virtual const TQValueList<MyMoneySecurity> securityList(void) const = 0;
/**
* This method is used to return the standard liability account
@@ -194,12 +194,12 @@ public:
/**
* This method is used to add one account as sub-ordinate to another
- * (parent) account. The objects that are passed will be modified
+ * (tqparent) account. The objects that are passed will be modified
* accordingly.
*
* An exception will be thrown upon error conditions.
*
* @param parent parent account the account should be added to
* @param account the account to be added
*
* @deprecated This method is only provided as long as we provide
@@ -207,7 +207,7 @@ public:
* this compatability mode this method will disappear from
* this interface!
*/
- virtual void addAccount(MyMoneyAccount& parent, MyMoneyAccount& account) = 0;
+ virtual void addAccount(MyMoneyAccount& tqparent, MyMoneyAccount& account) = 0;
/**
* This method is used to create a new payee
@@ -227,7 +227,7 @@ public:
/**
* Adds an institution to the storage. A
* respective institution-ID will be generated within this record.
* The ID is stored as QString in the object passed as argument.
*
* An exception will be thrown upon error conditions.
*
@@ -244,7 +244,7 @@ public:
/**
* Adds a transaction to the file-global transaction pool. A respective
* transaction-ID will be generated within this record. The ID is stored
* as QString with the object.
*
* An exception will be thrown upon error conditions.
*
@@ -262,15 +262,15 @@ public:
*/
virtual void addTransaction(MyMoneyTransaction& transaction, const bool skipAccountUpdate = false) = 0;
- virtual void loadAccounts(const QMap<QString, MyMoneyAccount>& map) = 0;
- virtual void loadTransactions(const QMap<QString, MyMoneyTransaction>& map) = 0;
- virtual void loadInstitutions(const QMap<QString, MyMoneyInstitution>& map) = 0;
- virtual void loadPayees(const QMap<QString, MyMoneyPayee>& map) = 0;
- virtual void loadSchedules(const QMap<QString, MyMoneySchedule>& map) = 0;
- virtual void loadSecurities(const QMap<QString, MyMoneySecurity>& map) = 0;
- virtual void loadCurrencies(const QMap<QString, MyMoneySecurity>& map) = 0;
- virtual void loadReports( const QMap<QString, MyMoneyReport>& reports ) = 0;
- virtual void loadBudgets( const QMap<QString, MyMoneyBudget>& budgets ) = 0;
+ virtual void loadAccounts(const TQMap<TQString, MyMoneyAccount>& map) = 0;
+ virtual void loadTransactions(const TQMap<TQString, MyMoneyTransaction>& map) = 0;
+ virtual void loadInstitutions(const TQMap<TQString, MyMoneyInstitution>& map) = 0;
+ virtual void loadPayees(const TQMap<TQString, MyMoneyPayee>& map) = 0;
+ virtual void loadSchedules(const TQMap<TQString, MyMoneySchedule>& map) = 0;
+ virtual void loadSecurities(const TQMap<TQString, MyMoneySecurity>& map) = 0;
+ virtual void loadCurrencies(const TQMap<TQString, MyMoneySecurity>& map) = 0;
+ virtual void loadReports( const TQMap<TQString, MyMoneyReport>& reports ) = 0;
+ virtual void loadBudgets( const TQMap<TQString, MyMoneyBudget>& budgets ) = 0;
virtual void loadPrices(const MyMoneyPriceList& list) = 0;
virtual unsigned long accountId(void) const = 0;
@@ -296,10 +296,10 @@ public:
* from the container. It is meant to be used for permanent storage
* functionality. See MyMoneyKeyValueContainer::pairs() for details.
*
* @return QMap<QString, QString> containing all key/value pairs of
* this container.
*/
- virtual const QMap<QString, QString> pairs(void) const = 0;
+ virtual const TQMap<TQString, TQString> pairs(void) const = 0;
/**
* This method is used to initially store a set of key/value pairs
@@ -307,18 +307,18 @@ public:
* from permanent storage. See MyMoneyKeyValueContainer::setPairs()
* for details
*
* @param list const QMap<QString, QString> containing the set of
* key/value pairs to be loaded into the container.
*
* @note All existing key/value pairs in the container will be deleted.
*/
- virtual void setPairs(const QMap<QString, QString>& list) = 0;
+ virtual void setPairs(const TQMap<TQString, TQString>& list) = 0;
- virtual const QValueList<MyMoneySchedule> scheduleListEx( int scheduleTypes,
+ virtual const TQValueList<MyMoneySchedule> scheduleListEx( int scheduleTypes,
int scheduleOcurrences,
int schedulePaymentTypes,
- QDate startDate,
- const QStringList& accounts=QStringList()) const = 0;
+ TQDate startDate,
+ const TQStringList& accounts=TQStringList()) const = 0;
/**
* This method is used to retrieve the list of all currencies
@@ -326,9 +326,9 @@ public:
*
* An exception will be thrown upon erronous situations.
*
* @return QValueList of all MyMoneySecurity objects representing a currency.
*/
- virtual const QValueList<MyMoneySecurity> currencyList(void) const = 0;
+ virtual const TQValueList<MyMoneySecurity> currencyList(void) const = 0;
/**
* This method is used to retrieve the list of all reports
@@ -336,9 +336,9 @@ public:
*
* An exception will be thrown upon erronous situations.
*
* @return QValueList of all MyMoneyReport objects.
*/
- virtual const QValueList<MyMoneyReport> reportList( void ) const = 0;
+ virtual const TQValueList<MyMoneyReport> reportList( void ) const = 0;
/**
* This method is used to retrieve the list of all budgets
@@ -346,9 +346,9 @@ public:
*
* An exception will be thrown upon erronous situations.
*
* @return QValueList of all MyMoneyBudget objects.
*/
- virtual const QValueList<MyMoneyBudget> budgetList( void ) const = 0;
+ virtual const TQValueList<MyMoneyBudget> budgetList( void ) const = 0;
/**
@@ -86,26 +86,26 @@ public:
* file.
*
- * @param val QDate of last modification
+ * @param val TQDate of last modification
*/
@@ -86,26 +86,26 @@ public:
* This method returns a list of accounts inside the storage object.
*
- * @param list reference to QValueList receiving the account objects
+ * @param list reference to TQValueList receiving the account objects
*
* @note The standard accounts will not be returned
@@ -86,26 +86,26 @@ public:
* inside a MyMoneyStorage object
*
- * @return QMap containing the institution information
+ * @return TQMap containing the institution information
*/
@@ -113,25 +113,25 @@ public:
* the whole journal will be returned.
*
- * @param list reference to QValueList<MyMoneyTransaction> receiving
+ * @param list reference to TQValueList<MyMoneyTransaction> receiving
* the set of transactions
* @param filter MyMoneyTransactionFilter object with the match criteria
@@ -113,25 +113,25 @@ public:
* inside a MyMoneyStorage object
*
- * @return QValueList<MyMoneyPayee> containing the payee information
+ * @return TQValueList<MyMoneyPayee> containing the payee information
*/
@@ -194,12 +194,12 @@ public:
* An exception will be thrown upon error conditions.
*
- * @param parent parent account the account should be added to
+ * @param tqparent tqparent account the account should be added to
* @param account the account to be added
*
@@ -227,7 +227,7 @@ public:
* Adds an institution to the storage. A
* respective institution-ID will be generated within this record.
- * The ID is stored as QString in the object passed as argument.
+ * The ID is stored as TQString in the object passed as argument.
*
* An exception will be thrown upon error conditions.
@@ -244,7 +244,7 @@ public:
* Adds a transaction to the file-global transaction pool. A respective
* transaction-ID will be generated within this record. The ID is stored
- * as QString with the object.
+ * as TQString with the object.
*
* An exception will be thrown upon error conditions.
@@ -296,10 +296,10 @@ public:
* functionality. See MyMoneyKeyValueContainer::pairs() for details.
*
- * @return QMap<QString, QString> containing all key/value pairs of
+ * @return TQMap<TQString, TQString> containing all key/value pairs of
* this container.
*/
@@ -307,18 +307,18 @@ public:
* for details
*
- * @param list const QMap<QString, QString> containing the set of
+ * @param list const TQMap<TQString, TQString> containing the set of
* key/value pairs to be loaded into the container.
*
@@ -326,9 +326,9 @@ public:
* An exception will be thrown upon erronous situations.
*
- * @return QValueList of all MyMoneySecurity objects representing a currency.
+ * @return TQValueList of all MyMoneySecurity objects representing a currency.
*/
@@ -336,9 +336,9 @@ public:
* An exception will be thrown upon erronous situations.
*
- * @return QValueList of all MyMoneyReport objects.
+ * @return TQValueList of all MyMoneyReport objects.
*/
@@ -346,9 +346,9 @@ public:
* An exception will be thrown upon erronous situations.
*
- * @return QValueList of all MyMoneyBudget objects.
+ * @return TQValueList of all MyMoneyBudget objects.
*/